@@ -7,7 +7,13 @@ import pytest
 from numpy.testing import assert_array_equal, assert_array_almost_equal
 from pytest import raises
 
-from pysteps.utils import arrays, conversion, dimension, transformation, aggregate_fields
+from pysteps.utils import (
+    arrays,
+    conversion,
+    dimension,
+    transformation,
+    aggregate_fields,
+)
 
 # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # arrays
@@ -363,56 +369,49 @@ def test_to_reflectivity(R, metadata, expected):
 
 test_data_not_trim = (
     # "data, window_size, axis, method, expected"
-    (
-        np.arange(6),
-        2,
-        0,
-        "mean",
-        np.array([0.5, 2.5, 4.5])
-    ),
+    (np.arange(6), 2, 0, "mean", np.array([0.5, 2.5, 4.5])),
     (
         np.arange(4 * 6).reshape(4, 6),
         (2, 3),
         (0, 1),
         "sum",
-        np.array([[24, 42], [96, 114]])
+        np.array([[24, 42], [96, 114]]),
     ),
     (
         np.arange(4 * 6).reshape(4, 6),
         (2, 2),
         (0, 1),
         "sum",
-        np.array([[14, 22, 30], [62, 70, 78]])
+        np.array([[14, 22, 30], [62, 70, 78]]),
     ),
     (
         np.arange(4 * 6).reshape(4, 6),
         2,
         (0, 1),
         "sum",
-        np.array([[14, 22, 30], [62, 70, 78]])
+        np.array([[14, 22, 30], [62, 70, 78]]),
     ),
     (
         np.arange(4 * 6).reshape(4, 6),
         (2, 3),
         (0, 1),
         "mean",
-        np.array([[4., 7.], [16., 19.]]),
+        np.array([[4.0, 7.0], [16.0, 19.0]]),
     ),
     (
         np.arange(4 * 6).reshape(4, 6),
         (2, 2),
         (0, 1),
         "mean",
-        np.array([[3.5, 5.5, 7.5], [15.5, 17.5, 19.5]])
+        np.array([[3.5, 5.5, 7.5], [15.5, 17.5, 19.5]]),
     ),
     (
         np.arange(4 * 6).reshape(4, 6),
         2,
         (0, 1),
         "mean",
-        np.array([[3.5, 5.5, 7.5], [15.5, 17.5, 19.5]])
+        np.array([[3.5, 5.5, 7.5], [15.5, 17.5, 19.5]]),
     ),
-
 )
 
 
@@ -429,26 +428,18 @@ def test_aggregate_fields(data, window_size, axis, method, expected):
     """
 
     assert_array_equal(
-        aggregate_fields(data, window_size, axis=axis, method=method),
-        expected,
+        aggregate_fields(data, window_size, axis=axis, method=method), expected,
     )
 
     # Test the trimming capabilities.
     data = np.pad(data, (0, 1))
     assert_array_equal(
-        aggregate_fields(data,
-                         window_size,
-                         axis=axis,
-                         method=method,
-                         trim=True),
+        aggregate_fields(data, window_size, axis=axis, method=method, trim=True),
         expected,
     )
 
     with raises(ValueError):
-        aggregate_fields(data,
-                         window_size,
-                         axis=axis,
-                         method=method)
+        aggregate_fields(data, window_size, axis=axis, method=method)
 
 
 def test_aggregate_fields_errors():
